@@ -6,8 +6,8 @@ library(knowYourCG)
 temp_dir <- tempdir()
 knowledgebase <- file.path(temp_dir, "ChromHMM.20220414.cm")
 query <- file.path(temp_dir, "mm10_f3_10cells.cg")
-knowledgebase_url <- "https://github.com/zhou-lab/KYCGKB_mm10/raw/refs/heads/main/ChromHMM.20220414.cm"
-query_url <- "https://github.com/zhou-lab/YAME_test/raw/refs/heads/main/input/cx/mm10_f3_10cells.cg"
+knowledgebase_url <- "https://zenodo.org/records/18175656/files/ChromHMM.20220414.cm"
+query_url <- "https://zenodo.org/records/18176004/files/mm10_f3_10cells.cg"
 download.file(knowledgebase_url, destfile = knowledgebase)
 download.file(query_url, destfile = query)
 
